import 'package:flutter/cupertino.dart';
import 'package:hive/hive.dart';

mixin Restorable<T> {
  @protected
  Box<T> _box;
  @protected
  String get key;
  @protected
  TypeAdapter<T> get typeAdapter;

  @protected
  Future<T> getStored() async {
    try {
      Hive.registerAdapter(typeAdapter);
      _box = await Hive.openBox(key);
      return _box.get(key);
    } catch (e) {
      Hive.deleteBoxFromDisk(key);
      _box = await Hive.openBox(key);
      return null;
    }
  }

  Future<void> save(T value) async {
    await _box?.put(key, value);
  }
}
